BlurredBackdropSheetController class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
show<T>({required BuildContext context, required Widget child, double blurIntensity = 15.0, Color? backgroundColor, BorderRadius? borderRadius, bool isDismissible = true, bool showDragHandle = true, Duration animationDuration = const Duration(milliseconds: 300), double? minHeight, double? maxHeight, double? initialHeight, VoidCallback? onDismissed, bool useRootNavigator = false})
→ Future<T?>
-
Show a blurred backdrop sheet